@@ -5,14 +5,13 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="46"/>
-        <location filename="../mainwindow.cpp" line="76"/>
-        <location filename="../mainwindow.cpp" line="133"/>
-        <location filename="../mainwindow.cpp" line="146"/>
-        <location filename="../mainwindow.cpp" line="180"/>
-        <location filename="../mainwindow.cpp" line="188"/>
+        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="75"/>
+        <location filename="../mainwindow.cpp" line="129"/>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <location filename="../mainwindow.cpp" line="156"/>
         <source>MX Select Sound</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">בחירת שמע MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="28"/>
@@ -22,7 +21,7 @@
     <message>
         <location filename="../mainwindow.ui" line="64"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">הצגת עזרה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="67"/>
@@ -32,22 +31,22 @@
     <message>
         <location filename="../mainwindow.ui" line="74"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="103"/>
         <source>About this application</source>
-        <translation type="unfinished">מידע לגבי התוכנה הזו</translation>
+        <translation type="unfinished">על אודות יישום זה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="106"/>
         <source>About...</source>
-        <translation type="unfinished">אודות...</translation>
+        <translation type="unfinished">על אודות...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="113"/>
         <source>Alt+B</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="145"/>
@@ -57,12 +56,12 @@
     <message>
         <location filename="../mainwindow.ui" line="148"/>
         <source>Close</source>
-        <translation type="unfinished">סגור</translation>
+        <translation type="unfinished">סגירה</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="155"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="196"/>
@@ -85,76 +84,105 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="77"/>
+        <location filename="../mainwindow.cpp" line="75"/>
         <source>No sound cards/devices were found.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="89"/>
-        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="87"/>
+        <location filename="../mainwindow.cpp" line="98"/>
         <source>none</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">ללא</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="132"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>About MX Select Sound</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="133"/>
+        <location filename="../mainwindow.cpp" line="129"/>
         <source>Version: </source>
-        <translation type="unfinished">גרסה:</translation>
+        <translation type="unfinished">גירסה:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="134"/>
+        <location filename="../mainwindow.cpp" line="130"/>
         <source>Program for selecting the default sound card in MX Linux</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="136"/>
+        <location filename="../mainwindow.cpp" line="133"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">זכויות שמורות MX Linux</translation>
+        <translation type="unfinished">זכויות היוצרים (c) שמורות ל־MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="137"/>
-        <location filename="../mainwindow.cpp" line="146"/>
-        <source>License</source>
-        <translation type="unfinished">רשיון</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="138"/>
-        <source>Changelog</source>
+        <location filename="../mainwindow.cpp" line="134"/>
+        <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="139"/>
-        <source>Cancel</source>
-        <translation type="unfinished">ביטול</translation>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <source>%1 Help</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="156"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="189"/>
         <source>Could not play test sound.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../about.cpp" line="43"/>
+        <source>License</source>
+        <translation type="unfinished">רשיון</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="44"/>
+        <location filename="../about.cpp" line="54"/>
+        <source>Changelog</source>
+        <translation type="unfinished">יומן שינויים</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="45"/>
+        <source>Cancel</source>
+        <translation type="unfinished">ביטול</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="67"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished">&amp;סגירה</translation>
+    </message>
+</context>
 <context>
     <name>mxselectsound</name>
+    <message>
+        <source>MX Select Sound</source>
+        <translation type="vanished">בחירת שמע MX</translation>
+    </message>
+    <message>
+        <source>Display help </source>
+        <translation type="vanished">הצגת עזרה</translation>
+    </message>
     <message>
         <source>Help</source>
         <translation type="vanished">עזרה</translation>
     </message>
+    <message>
+        <source>Alt+H</source>
+        <translation type="vanished">Alt+H</translation>
+    </message>
     <message>
         <source>About this application</source>
-        <translation type="vanished">מידע לגבי התוכנה הזו</translation>
+        <translation type="vanished">על אודות יישום זה</translation>
     </message>
     <message>
         <source>About...</source>
-        <translation type="vanished">אודות...</translation>
+        <translation type="vanished">על אודות...</translation>
+    </message>
+    <message>
+        <source>Alt+B</source>
+        <translation type="vanished">Alt+B</translation>
     </message>
     <message>
         <source>Quit application</source>
@@ -162,27 +190,43 @@
     </message>
     <message>
         <source>Close</source>
-        <translation type="vanished">סגור</translation>
+        <translation type="vanished">סגירה</translation>
+    </message>
+    <message>
+        <source>Alt+N</source>
+        <translation type="vanished">Alt+N</translation>
     </message>
     <message>
         <source>Apply</source>
         <translation type="vanished">אשר</translation>
     </message>
+    <message>
+        <source>none</source>
+        <translation type="vanished">ללא</translation>
+    </message>
     <message>
         <source>Version: </source>
-        <translation type="vanished">גרסה:</translation>
+        <translation type="vanished">גירסה:</translation>
     </message>
     <message>
         <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">זכויות שמורות MX Linux</translation>
+        <translation type="vanished">זכויות היוצרים (c) שמורות ל־MX Linux</translation>
     </message>
     <message>
         <source>License</source>
         <translation type="vanished">רשיון</translation>
     </message>
+    <message>
+        <source>Changelog</source>
+        <translation type="vanished">יומן שינויים</translation>
+    </message>
     <message>
         <source>Cancel</source>
         <translation type="vanished">ביטול</translation>
     </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="vanished">&amp;סגירה</translation>
+    </message>
 </context>
 </TS>
