@@ -5,19 +5,18 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="46"/>
-        <location filename="../mainwindow.cpp" line="76"/>
-        <location filename="../mainwindow.cpp" line="133"/>
-        <location filename="../mainwindow.cpp" line="146"/>
-        <location filename="../mainwindow.cpp" line="180"/>
-        <location filename="../mainwindow.cpp" line="188"/>
+        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="75"/>
+        <location filename="../mainwindow.cpp" line="129"/>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <location filename="../mainwindow.cpp" line="156"/>
         <source>MX Select Sound</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Përzgjedhje Zëri MX</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="28"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Karta juaj e zërit parazgjedhje e tanishme është:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="64"/>
@@ -32,17 +31,17 @@
     <message>
         <location filename="../mainwindow.ui" line="74"/>
         <source>Alt+H</source>
-        <translation type="unfinished">Alt+H</translation>
+        <translation type="unfinished">Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="103"/>
         <source>About this application</source>
-        <translation type="unfinished">Rreth këtij aplikacioni</translation>
+        <translation type="unfinished">Mbi këtë aplikacion</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="106"/>
         <source>About...</source>
-        <translation type="unfinished">Rreth...</translation>
+        <translation type="unfinished">Mbi…</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="113"/>
@@ -57,93 +56,114 @@
     <message>
         <location filename="../mainwindow.ui" line="148"/>
         <source>Close</source>
-        <translation type="unfinished">Mbyll</translation>
+        <translation type="unfinished">Mbylle</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="155"/>
         <source>Alt+N</source>
-        <translation type="unfinished">Alt+N</translation>
+        <translation type="unfinished">Alt+M</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="196"/>
         <source>Apply</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Zbatoje</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="218"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Përzgjidhni një tjetër kartë zëri, në qoftë e nevojshme:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="244"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nëse kompjuteri juaj ka më shumë se një kartë zëri, mund të përdorni këtë aplikacion për të përzgjedhur njërën të jetë parazgjedhja. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="290"/>
         <source>Test current sound card</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Provoni kartën e tanishme të zërit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="77"/>
+        <location filename="../mainwindow.cpp" line="75"/>
         <source>No sound cards/devices were found.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">S’u gjetëm karta/pajisje zëri.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="89"/>
-        <location filename="../mainwindow.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="87"/>
+        <location filename="../mainwindow.cpp" line="98"/>
         <source>none</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">asnjë</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="132"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>About MX Select Sound</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Mbi Përzgjedhje Zëri MX</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="129"/>
+        <source>Version: </source>
+        <translation type="unfinished">Version:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="130"/>
+        <source>Program for selecting the default sound card in MX Linux</source>
+        <translation type="unfinished">Program për përzgjedhje të kartës parazgjedhje të zërit në MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="133"/>
-        <source>Version: </source>
-        <translation type="unfinished">Versioni:</translation>
+        <source>Copyright (c) MX Linux</source>
+        <translation type="unfinished">Të drejta kopjimi (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="134"/>
-        <source>Program for selecting the default sound card in MX Linux</source>
+        <source>%1 License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="136"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished">Të drejtat e rezervuara (c) MX Linux</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="137"/>
-        <location filename="../mainwindow.cpp" line="146"/>
-        <source>License</source>
-        <translation type="unfinished">Liçensa</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="138"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Ndryshimet</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="139"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Anullo</translation>
+        <location filename="../mainwindow.cpp" line="148"/>
+        <source>%1 Help</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="156"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Mbyll</translation>
+        <source>Could not play test sound.</source>
+        <translation type="unfinished">S’u luajt dot tingull prove.</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../about.cpp" line="43"/>
+        <source>License</source>
+        <translation type="unfinished">Licencë</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="189"/>
-        <source>Could not play test sound.</source>
-        <translation type="unfinished"></translation>
+        <location filename="../about.cpp" line="44"/>
+        <location filename="../about.cpp" line="54"/>
+        <source>Changelog</source>
+        <translation type="unfinished">Regjistër ndryshimesh</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="45"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Anuloje</translation>
+    </message>
+    <message>
+        <location filename="../about.cpp" line="67"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished">&amp;Mbylle</translation>
     </message>
 </context>
 <context>
     <name>mxselectsound</name>
+    <message>
+        <source>MX Select Sound</source>
+        <translation type="vanished">Përzgjedhje Zëri MX</translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Karta juaj e zërit parazgjedhje e tanishme është:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
     <message>
         <source>Display help </source>
         <translation type="vanished">Shfaq ndihmë</translation>
@@ -154,15 +174,15 @@
     </message>
     <message>
         <source>Alt+H</source>
-        <translation type="vanished">Alt+H</translation>
+        <translation type="vanished">Alt+N</translation>
     </message>
     <message>
         <source>About this application</source>
-        <translation type="vanished">Rreth këtij aplikacioni</translation>
+        <translation type="vanished">Mbi këtë aplikacion</translation>
     </message>
     <message>
         <source>About...</source>
-        <translation type="vanished">Rreth...</translation>
+        <translation type="vanished">Mbi…</translation>
     </message>
     <message>
         <source>Alt+B</source>
@@ -174,35 +194,71 @@
     </message>
     <message>
         <source>Close</source>
-        <translation type="vanished">Mbyll</translation>
+        <translation type="vanished">Mbylle</translation>
     </message>
     <message>
         <source>Alt+N</source>
-        <translation type="vanished">Alt+N</translation>
+        <translation type="vanished">Alt+M</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation type="vanished">Zbatoje</translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Përzgjidhni një tjetër kartë zëri, në qoftë e nevojshme:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Nëse kompjuteri juaj ka më shumë se një kartë zëri, mund të përdorni këtë aplikacion për të përzgjedhur njërën të jetë parazgjedhja. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <source>Test current sound card</source>
+        <translation type="vanished">Provoni kartën e tanishme të zërit</translation>
+    </message>
+    <message>
+        <source>No sound cards/devices were found.</source>
+        <translation type="vanished">S’u gjetëm karta/pajisje zëri.</translation>
+    </message>
+    <message>
+        <source>none</source>
+        <translation type="vanished">asnjë</translation>
+    </message>
+    <message>
+        <source>About MX Select Sound</source>
+        <translation type="vanished">Mbi Përzgjedhje Zëri MX</translation>
     </message>
     <message>
         <source>Version: </source>
-        <translation type="vanished">Versioni:</translation>
+        <translation type="vanished">Version:</translation>
+    </message>
+    <message>
+        <source>Program for selecting the default sound card in MX Linux</source>
+        <translation type="vanished">Program për përzgjedhje të kartës parazgjedhje të zërit në MX Linux</translation>
     </message>
     <message>
         <source>Copyright (c) MX Linux</source>
-        <translation type="vanished">Të drejtat e rezervuara (c) MX Linux</translation>
+        <translation type="vanished">Të drejta kopjimi (c) MX Linux</translation>
     </message>
     <message>
         <source>License</source>
-        <translation type="vanished">Liçensa</translation>
+        <translation type="vanished">Licencë</translation>
     </message>
     <message>
         <source>Changelog</source>
-        <translation type="vanished">Ndryshimet</translation>
+        <translation type="vanished">Regjistër ndryshimesh</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="vanished">Anullo</translation>
+        <translation type="vanished">Anuloje</translation>
     </message>
     <message>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;Mbyll</translation>
+        <translation type="vanished">&amp;Mbylle</translation>
+    </message>
+    <message>
+        <source>Could not play test sound.</source>
+        <translation type="vanished">S’u luajt dot tingull prove.</translation>
     </message>
 </context>
 </TS>
